# deep_orderbook
Orderbooks contain so much more organic informations than moving averages... 


(Work in progress on my free time)


![books](https://raw.githubusercontent.com/gQuantCoder/deep_orderbook/master/images/01.png?raw=true "Orderbooks and alpha")
